# Gemini 2 Models via GenAI SDK

GenAI SDK supports running Gemini 2.0 models. Configure either Google Vertex AI credentials or Google AI API Key. You will be prompted to enter Google AI API key only if you do not provide vertex AI credentials.

1. Select `Google GenAI API` as the AI backend.

![gemini201](https://github.com/user-attachments/assets/9a2295d9-7adc-42d6-935b-d0dbdfe9b714)

2. Either enter Vertex AI credentials information or Google AI API key for the configurations. 

![gemini202](https://github.com/user-attachments/assets/1f97cf66-624d-4d35-b1cc-2876e59f51e9)

3. Select a Gemini model

![gemini203](https://github.com/user-attachments/assets/eb6eed5a-df85-41e3-b657-53c93a5cffba)
